power_cogs.config.base package — power_cogs 0.1.0 documentation

# power_cogs.config.base package

## Submodules

## power_cogs.config.base.base_config module

class `power_cogs.config.base.base_config.` `BaseDatasetConfig`(_target_: 'str' = '???')

  Bases: `object`

class `power_cogs.config.base.base_config.` `BaseLoggingConfig`(checkpoint_path: 'str' = 'checkpoints', tensorboard_log_path: 'Optional[str]' = None)

  Bases: `object`

  `checkpoint_path` = 'checkpoints'
  `tensorboard_log_path` = None

class `power_cogs.config.base.base_config.` `BaseModelConfig`(_target_: 'str' = '???')

  Bases: `object`

class `power_cogs.config.base.base_config.` `BaseTrainerConfig`(defaults: 'List[Any]' = <factory>, _target_: 'str' = '???', name: 'Optional[str]' = None, pretrained_path: 'Optional[str]' = None, visualize_output: 'bool' = True, use_cuda: 'bool' = False, device_id: 'int' = 0, early_stoppage: 'bool' = False, loss_threshold: 'float' = -inf, batch_size: 'int' = 32, epochs: 'int' = 100, checkpoint_interval: 'int' = 100, num_samples: 'Optional[int]' = None, model_config: 'Any' = '???', dataset_config: 'Any' = '???', optimizer_config: 'Any' = '???', scheduler_config: 'Any' = '???', logging_config: 'Any' = '???', dataloader_config: 'Any' = '???', tune_config: 'Any' = '???', config: 'Any' = <factory>)

  Bases: `object`

  `batch_size` = 32
  `checkpoint_interval` = 100
  `dataloader_config` = '???'
  `dataset_config` = '???'
  `device_id` = 0
  `early_stoppage` = False
  `epochs` = 100
  `logging_config` = '???'
  `loss_threshold` = -inf
  `model_config` = '???'
  `name` = None
  `num_samples` = None
  `optimizer_config` = '???'
  `pretrained_path` = None
  `scheduler_config` = '???'
  `tune_config` = '???'
  `use_cuda` = False
  `visualize_output` = True

class `power_cogs.config.base.base_config.` `Config`(defaults: 'List[Any]' = <factory>, trainer: 'Any' = '???')

  Bases: `object`

  `trainer` = '???'

`power_cogs.config.base.base_config.` `make_trainer_defaults`(overrides=[])

## Module contents

`power_cogs.config.base.` `make_trainer_defaults`(overrides=[])

class `power_cogs.config.base.` `BaseModelConfig`(_target_: 'str' = '???')

  Bases: `object`

class `power_cogs.config.base.` `BaseDatasetConfig`(_target_: 'str' = '???')

  Bases: `object`

class `power_cogs.config.base.` `BaseLoggingConfig`(checkpoint_path: 'str' = 'checkpoints', tensorboard_log_path: 'Optional[str]' = None)

  Bases: `object`

  `checkpoint_path` = 'checkpoints'
  `tensorboard_log_path` = None

class `power_cogs.config.base.` `BaseTrainerConfig`(defaults: 'List[Any]' = <factory>, _target_: 'str' = '???', name: 'Optional[str]' = None, pretrained_path: 'Optional[str]' = None, visualize_output: 'bool' = True, use_cuda: 'bool' = False, device_id: 'int' = 0, early_stoppage: 'bool' = False, loss_threshold: 'float' = -inf, batch_size: 'int' = 32, epochs: 'int' = 100, checkpoint_interval: 'int' = 100, num_samples: 'Optional[int]' = None, model_config: 'Any' = '???', dataset_config: 'Any' = '???', optimizer_config: 'Any' = '???', scheduler_config: 'Any' = '???', logging_config: 'Any' = '???', dataloader_config: 'Any' = '???', tune_config: 'Any' = '???', config: 'Any' = <factory>)

  Bases: `object`

  `batch_size` = 32
  `checkpoint_interval` = 100
  `dataloader_config` = '???'
  `dataset_config` = '???'
  `device_id` = 0
  `early_stoppage` = False
  `epochs` = 100
  `logging_config` = '???'
  `loss_threshold` = -inf
  `model_config` = '???'
  `name` = None
  `num_samples` = None
  `optimizer_config` = '???'
  `pretrained_path` = None
  `scheduler_config` = '???'
  `tune_config` = '???'
  `use_cuda` = False
  `visualize_output` = True

class `power_cogs.config.base.` `Config`(defaults: 'List[Any]' = <factory>, trainer: 'Any' = '???')

  Bases: `object`

  `trainer` = '???'